Learn R Programming

gsrsb (version 1.2.1)

cdBoundary: Lower and Upper Bounds Generator

Description

Generate lower and upper bounds for programs calculating the secondary endpoint's type I error when the correlation rho between the primary endpoint and the secondary endpoint equals 1.

Usage

cdBoundary(cvec, dvec, gammaVec, dlt, upper = TRUE)

Value

lower and upper bounds for programs calculating the secondary endpoint's type I error when the correlation rho is 1.

Arguments

cvec

primary boundary.

dvec

secondary boundary.

gammaVec

square root of information vector.

dlt

test statistic of the primary endpoint follows a normal distribution with mean dlt and standard deviation 1.

upper

type of bounds, upper bound is TRUE, lower bound is FALSE.

Author

Jiangtao Gou

Details

This function generates upper and lower bounds for further computation. For more details, refer to Tamhane et al. (2018, Biometrics), section 4.2.

References

Tamhane, A. C., Gou, J., Jennison, C., Mehta, C. R., and Curto, T. (2018). A gatekeeping procedure to test a primary and a secondary endpoint in a group sequential design with multiple interim looks. Biometrics, 74(1), 40-48. Gou, J. (2022). Sample size optimization and initial allocation of the significance levels in group sequential trials with multiple endpoints. Biometrical Journal, 64(2), 301–311.

Examples

Run this code
cvec <- rep(1.992,3)
dvec <- c(1.535*sqrt(3),1.535*sqrt(3/2),1.535)
gammaVec <- c(sqrt(1/3),sqrt(2/3),1)
dlt <- 2
uBoundary <- cdBoundary(cvec, dvec, gammaVec, dlt, upper=TRUE)

Run the code above in your browser using DataLab