Learn R Programming

gsrsb (version 1.2.1)

genCorrMat: Correlation Matrix Generator

Description

Generate correlation matrix between standardized sample mean test statistics for the two endpoint at different looks.

Usage

genCorrMat(gammaVec, type, rhoPS = 0)

Value

correlation matrix, K by K for primary endpoint, (K+1) by (K+1) for secondary endpoint, where K is the number of interims.

Arguments

gammaVec

a vector which contains gamma_(1), ..., gamma_(K-1), gamma_(K), square root of information vector.

type

type of primary or secondary endpoint. For primary endpoint calculation, type is 1, the returned matrix is K by K. For secondary endpoint calculation, type is 2, the returned matrix is (K+1) by (K+1).

rhoPS

correlation between primary and secondary endpoints.

Author

Jiangtao Gou

Fengqing (Zoe) Zhang

Details

This function generates correlation matrix between different mean statistics. For more details, refer to Tamhane et al. (2018, Biometrics), section 2.

References

Tamhane, A. C., Gou, J., Jennison, C., Mehta, C. R., and Curto, T. (2018). A gatekeeping procedure to test a primary and a secondary endpoint in a group sequential design with multiple interim looks. Biometrics, 74(1), 40-48. Tamhane, A. C., & Gou, J. (2022). Chapter 2 - Multiple test procedures based on p-values. In X. Cui, T. Dickhaus, Y. Ding, & J. C. Hsu (Eds.), Handbook of multiple comparisons (Vol. 45, pp. 11–34).

Examples

Run this code
corrMat <- genCorrMat(gammaVec=c(sqrt(1/3), sqrt(2/3), 1), type=2, rhoPS = 0.3)

Run the code above in your browser using DataLab