Learn R Programming

gsrsb (version 1.2.1)

ldPrimaryBoundary: Calculate Primary Boundaries, the Error Spending Approach

Description

Primary boundaries calculation of Lan-DeMets OBF and POC.

Usage

ldPrimaryBoundary(tVec, alpha, type = 1, initIntvl = c(0.8, 8))

Value

a vector of primary boundaries.

Arguments

tVec

a vector of information, gammaVec = sqrt(tVec).

alpha

significance level

type

type of sequential procedure. OBF is 1, POC is 2.

initIntvl

paramter for function uniroot (two numbers)

Author

Jiangtao Gou

References

Lan, K. K. G., and Demets, D. L. (1983). Discrete sequential boundaries for clinical trials. Biometrika 70, 659-663.

Tamhane, A. C., Gou, J., Jennison, C., Mehta, C. R., and Curto, T. (2018). A gatekeeping procedure to test a primary and a secondary endpoint in a group sequential design with multiple interim looks. Biometrics, 74(1), 40-48.

Gou, J. (2023). Trigger strategy in repeated tests on multiple hypotheses. Statistics in Biopharmaceutical Research, 15(1), 133–140.

See Also

primaryBoundary