Learn R Programming

gsrsb (version 1.2.1)

primaryBoundary: Calculate Primary Boundaries, Standard Approach

Description

Primary boundaries calculation of standard (original) OBF and POC.

Usage

primaryBoundary(gammaVec, alpha, type = 1, initIntvl = c(1, 4))

Value

original OBF and POC boundaries (primary endpoints) (a number, c_(K)).

Arguments

gammaVec

a vector of square root of information.

alpha

significance level

type

type of sequential procedure. OBF is 1, POC is 2.

initIntvl

paramter for function uniroot (two numbers)

Author

Jiangtao Gou

References

Tamhane, A. C., Gou, J., Jennison, C., Mehta, C. R., and Curto, T. (2017+). A gatekeeping procedure to test a primary and a secondary endpoint in a group sequential design with multiple interim looks. Biometrics, to appear.

See Also

ldPrimaryBoundary