Learn R Programming

gsrsb (version 1.2.1)

secondaryBoundaryVec: Calculate Refined Secondary Boundaries and Nominal Significance

Description

Refined secondary boundaries, and nominal significance for the secondary endpoint are calculated.

Usage

secondaryBoundaryVec(
  alpha,
  tVec,
  pOBF = TRUE,
  sOBF = FALSE,
  LanDeMets = FALSE,
  initIntvl = c(0.8, 8)
)

Value

a result list including refined secondary boundary and the nominal significance for the secondary endpoint.

Arguments

alpha

type I error probability.

tVec

vector of relative information levels. The last element in the vector is 1.

pOBF

type of primary boundary, TURE is the O'Brien-Fleming boundary, FALSE is the Pocock boundary.

sOBF

type of secondary boundary, TURE is the O'Brien-Fleming boundary, FALSE is the Pocock boundary.

LanDeMets

type of boundary, TRUE is the error spending approach, FALSE is the original approach.

initIntvl

computing paramter, a pair of numbers containing the end-points of the interval to be searched for the root.

Author

Jiangtao Gou

Details

This function gives a list including refined secondary boundary and the nominal significance for the secondary endpoint. There are a computing parameter initIntvl. Parameter initIntvl contains the end-points of the interval to be searched for the root. For Lan-DeMets error spending approach, the lower end point should choose a number slightly less than 1, and the upper end point should choose a number between 4 and 10.

References

Glimm, E., Maurer, W., and Bretz, F. (2010). Hierarchical testing of multiple endpoints in group-sequential trials. Statistics in Medicine 29, 219-228.

Hung, H. M. J., Wang, S.-J., and O'Neill, R. (2007). Statistical considerations for testing multiple endpoints in group sequential or adaptive clinical trials. Journal of Biopharmaceutical Statistics 17, 1201-1210.

Jennison, C. and Turnbull, B. W. (2000). Group Sequential Methods with Applications to Clinical Trials. Chapman and Hall/CRC, New York.

Lan, K. K. G., and Demets, D. L. (1983). Discrete sequential boundaries for clinical trials. Biometrika 70, 659-663.

O'Brien, P. C., and Fleming, T. R. (1979). A multiple testing procedure for clinical trials. Biometrics 35, 549-556.

Pocock, S. J. (1977). Group sequential methods in the design and analysis of clinical trials. Biometrika 64, 191-199.

Tamhane, A. C., Mehta, C. R., and Liu, L. (2010). Testing a primary and a secondary endpoint in a group sequential design. Biometrics 66, 1174-1184.

Tamhane, A. C., Gou, J., Jennison, C., Mehta, C. R., and Curto, T. (2018). A gatekeeping procedure to test a primary and a secondary endpoint in a group sequential design with multiple interim looks. Biometrics, 74, 40-48.

See Also

secondaryBoundaryVecLD, secondaryBoundaryVecOrig

Examples

Run this code
require(mvtnorm)
require(ldbounds)
result <- secondaryBoundaryVec(alpha=0.025,tVec=c(1/2,1),pOBF=TRUE,sOBF=FALSE,
       LanDeMets=FALSE,initIntvl=c(0.8,5))
result$secondaryBoundary
result$nomialSignificance

Run the code above in your browser using DataLab