Standard refined secondary boundaries, and nominal significance for the secondary endpoint are calculated by using the standard (original) approach.
secondaryBoundaryVecOrig(
alpha,
tVec,
primaryOBF = TRUE,
secondaryOBF = FALSE,
initIntvl = c(1, 8)
)a result list including standard refined secondary boundary and the nominal significance for the secondary endpoint.
type I error probability.
vector of relative information levels. The last element in the vector is 1.
type of primary boundary, TURE is the O'Brien-Fleming boundary, FALSE is the Pocock boundary.
type of secondary boundary, TURE is the O'Brien-Fleming boundary, FALSE is the Pocock boundary.
computing paramter, a pair of numbers containing the end-points of the interval to be searched for the root.
Jiangtao Gou
This function uses the standard approach (O'Brien and Fleming 1979, Pocock 1977),
and gives a list including refined secondary boundary and the nominal significance for the secondary endpoint.
There is a computing parameter initIntvl.
Parameter initIntvl contains the end-points of the interval to be searched for the root.
The lower end point should choose a number around 1,
and the upper end point should choose a number between 4 and 10.
Glimm, E., Maurer, W., and Bretz, F. (2010). Hierarchical testing of multiple endpoints in group-sequential trials. Statistics in Medicine 29, 219-228.
Hung, H. M. J., Wang, S.-J., and O'Neill, R. (2007). Statistical considerations for testing multiple endpoints in group sequential or adaptive clinical trials. Journal of Biopharmaceutical Statistics 17, 1201-1210.
Jennison, C. and Turnbull, B. W. (2000). Group Sequential Methods with Applications to Clinical Trials. Chapman and Hall/CRC, New York.
O'Brien, P. C., and Fleming, T. R. (1979). A multiple testing procedure for clinical trials. Biometrics 35, 549-556.
Pocock, S. J. (1977). Group sequential methods in the design and analysis of clinical trials. Biometrika 64, 191-199.
Tamhane, A. C., Mehta, C. R., and Liu, L. (2010). Testing a primary and a secondary endpoint in a group sequential design. Biometrics 66, 1174-1184.
Tamhane, A. C., Gou, J., Jennison, C., Mehta, C. R., and Curto, T. (2018). A gatekeeping procedure to test a primary and a secondary endpoint in a group sequential design with multiple interim looks. Biometrics, 74, 40-48.
secondaryBoundaryVec, secondaryBoundaryVecLD
require(mvtnorm)
require(ldbounds)
result <- secondaryBoundaryVecOrig(alpha=0.025,tVec=c(1/2,1),primaryOBF=TRUE,
secondaryOBF=FALSE, initIntvl=c(1,4))
result$secondaryBoundary
result$nomialSignificance
Run the code above in your browser using DataLab