Primary boundaries calculation of standard (original) OBF and POC.
primaryBoundary(gammaVec, alpha, type = 1, initIntvl = c(1, 4))original OBF and POC boundaries (primary endpoints) (a number, c_(K)).
a vector of square root of information.
significance level
type of sequential procedure. OBF is 1, POC is 2.
paramter for function uniroot (two numbers)
Jiangtao Gou
Tamhane, A. C., Gou, J., Jennison, C., Mehta, C. R., and Curto, T. (2017+). A gatekeeping procedure to test a primary and a secondary endpoint in a group sequential design with multiple interim looks. Biometrics, to appear.
ldPrimaryBoundary